/vpcs/{vpcs_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /vpcs/{vpcs_id}

Contents

- /vpcs/{vpcs_id}
  - GET /vpcs/{vpcs_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /vpcs/{vpcs_id}
    - Parameters
    - Response status codes
    - Input
    - Output

## GET /vpcs/{vpcs_id}

Get informations about a VPCS

### Parameters

- vpcs_id: Id of VPCS instance

### Response status codes

- 200: OK

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
vpcs_id | ✔ | integer | VPCS device instance ID

## PUT /vpcs/{vpcs_id}

Update VPCS informations

### Parameters

- vpcs_id: Id of VPCS instance

### Response status codes

- 200: OK

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
vpcs_id | ✔ | integer | VPCS device instance ID

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
name | ✔ | string | VPCS device name
vpcs_id | ✔ | integer | VPCS device instance ID

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »